Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(97)

Unified Diff: ui/views/controls/table/table_view_unittest.cc

Issue 2785473003: views::TableView - request focus on tap. (Closed)
Patch Set: rebase Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/views/controls/table/table_view.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/views/controls/table/table_view_unittest.cc
diff --git a/ui/views/controls/table/table_view_unittest.cc b/ui/views/controls/table/table_view_unittest.cc
index e727168134fcfaed95648969550f505e64f745c2..3f29b417ba37972c069074e3865203ec2d1f6d0b 100644
--- a/ui/views/controls/table/table_view_unittest.cc
+++ b/ui/views/controls/table/table_view_unittest.cc
@@ -734,8 +734,10 @@ TEST_F(TableViewTest, SelectOnTap) {
TableViewObserverImpl observer;
table_->set_observer(&observer);
- // Tap on the first row, should select it.
+ // Tap on the first row, should select it and focus the table.
+ EXPECT_FALSE(table_->HasFocus());
TapOnRow(0);
+ EXPECT_TRUE(table_->HasFocus());
EXPECT_EQ(1, observer.GetChangedCountAndClear());
EXPECT_EQ("active=0 anchor=0 selection=0", SelectionStateAsString());
« no previous file with comments | « ui/views/controls/table/table_view.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698